<?php
/***************************************************************************
 *                             admin_newfeeds.php
 *                            -------------------
 *   Description:
 *   	This file contains the admistration functions for the maintenance
 *   	of newsfeed.
 *
 *   Last Updated	:	Wednesday, March 21, 2007
 *   Author		:	John MacAuley - The Comic Haven
 *   E-mail		:	hacksaw@thecomichaven.com
 *
 *   Version		: 	1.2.0
 *
 *   Changes:
 *   1.2.0      - Added even more newsfeed configuration options for feed
 *                specific features.  Added code to hide Add/Edit newsfeed
 *                table until user selects operation (table got too big).
 *                Moved most feed configuration options from main table
 *                columns into a hidden table that can be opened by the
 *                user using the bird beak.
 *
 *   1.1	- Added newsfeed configuration options for all feed specific
 *   		  features added (podcast, html, and content display).
 *
 ***************************************************************************/

define('IN_PHPBB', 1);

if(!empty($setmodules))
{
	$filename = basename(__FILE__);
	$module['FIND']['Input Newsfeeds'] = $filename;

	return;
}

//
// Load default header
//
$no_page_header = TRUE;
$phpbb_root_path = './../';
require($phpbb_root_path . 'extension.inc');
require('./pagestart.' . $phpEx);

include($phpbb_root_path . 'includes/find_config.'.$phpEx);

/***************************************************************************
 *                      getForumList
 *                      ------------
 *   Description:
 *   	This function builds an HTML select element using forum names
 *   	available on this phpBB	installation.  The active item is set
 *   	if provided. 
 *
 *   Last Updated   	:   	Monday, March 5, 2007
 *   Author		:	John MacAuley - The Comic Haven
 *   E-mail		:	hacksaw@thecomichaven.com
 *
 *   Parameters:
 *       $db 		- phpBB database connector to query.
 *       $select 	- Forum to set as active in select list.
 *
 *   Returns:
 *   	String 		- The select HTML element.
 *
 *   Changes:
 *   1.2.0		- New function.
 *
 ***************************************************************************/
function getForumList($db, $select)
{
  // Get the list of forums and catgories.
  $sql = "SELECT f.*
      FROM " . FORUMS_TABLE . " f, " . CATEGORIES_TABLE . " c
	  WHERE c.cat_id = f.cat_id
	  ORDER BY c.cat_order ASC, f.forum_order ASC";

  if (!($result = $db->sql_query($sql)))
  {
      message_die(GENERAL_ERROR, "Could not obtain forum list from database", "",
	      __LINE__, __FILE__, $sql);
  }

  $forum_rows = $db->sql_fetchrowset($result);
  $db->sql_freeresult($result);

  // Build a drop down select list of forums.
  $select_list = '<select name="' . POST_FORUM_URL . '">';
  for ($i = 0; $i < count($forum_rows); $i++)
  {
    $select_list .= '<option value="' . $forum_rows[$i]['forum_id'] . '"';
    if ($forum_rows[$i]['forum_id'] == $select)
    {
      $select_list .= ' Selected ';
    }
    else
    {
      $select_list .= '';
    }
    $select_list .= '>' . $forum_rows[$i]['forum_name'] . '</option>';

  }

  $select_list .= '</select>';

  return($select_list);

} /* getForumList() */

/***************************************************************************
 *                      
 * Main code section.
 *
 ***************************************************************************/

// Try and set some system settings to hopefully get round problems with
// security settings on hosting providers.
@set_time_limit(120);
@ini_set("safe_mode", "0");
@ini_set("allow_url_fopen", "1");

// Include the newsfeed lang_admin file.
$use_lang = (!file_exists($phpbb_root_path . 'language/lang_' . $board_config['default_lang'] . '/lang_admin_find.'.$phpEx) ) ? 'english' : $board_config['default_lang'];
include($phpbb_root_path . 'language/lang_' . $use_lang . '/lang_admin_find.' . $phpEx);

// Initialise the mode.
$mode = ((isset($HTTP_POST_VARS['new_newsfeed']) ||
	  isset($HTTP_GET_VARS['new_newsfeed'])) ? 'new' :
       	((isset($HTTP_POST_VARS['add_newsfeed']) ||
	  isset($HTTP_GET_VARS['add_newsfeed'])) ? 'add' :
	((isset($HTTP_POST_VARS['edit_newsfeed']) ||
	  isset($HTTP_GET_VARS['edit_newsfeed'])) ? 'save' :
	((isset($HTTP_POST_VARS[POST_NEWSFEED_URL]) ||
	  isset($HTTP_GET_VARS[POST_NEWSFEED_URL])) ? 'edit' :
	((isset($HTTP_POST_VARS['delete_newsfeed']) ||
	  isset($HTTP_GET_VARS['delete_newsfeed'])) ? 'delete' :
	((isset($HTTP_POST_VARS['execute_newsfeed']) ||
	  isset($HTTP_GET_VARS['execute_newsfeed'])) ? 'execute' : ''))))));

// Are we adding a new newsfeed or saving the updates to an existing newsfeed?
if ( $mode == 'add' || $mode == 'save' )
{
    // initiailise the various variables
    $forum_id = ( (isset($HTTP_POST_VARS[POST_FORUM_URL]) ) ?
		intval($HTTP_POST_VARS[POST_FORUM_URL]) :
		( (isset($HTTP_GET_VARS[POST_FORUM_URL]) ) ?
		intval($HTTP_GET_VARS[POST_FORUM_URL]) : 0 ));

    $newsfeed_url = str_replace("\'", "''",
	    trim((isset($HTTP_POST_VARS['NEWSFEED_URL'])) ?
	    $HTTP_POST_VARS['NEWSFEED_URL'] :
	    $HTTP_GET_VARS['NEWSFEED_URL']));

    $newsfeed_name = trim((isset($HTTP_POST_VARS['NEWSFEED_NAME'])) ?
	    $HTTP_POST_VARS['NEWSFEED_NAME'] :
	    $HTTP_GET_VARS['NEWSFEED_NAME']);

    $newsfeed_limit = ((isset($HTTP_POST_VARS['NEWSFEED_LIMIT']) ) ?
	    intval($HTTP_POST_VARS['NEWSFEED_LIMIT']) :
	    ((isset($HTTP_GET_VARS['NEWSFEED_LIMIT']) ) ?
	    intval($HTTP_GET_VARS['NEWSFEED_LIMIT']) : 5 ));

    $newsfeed_encoding = trim((isset($HTTP_POST_VARS['NEWSFEED_ENCODING'])) ?
	    $HTTP_POST_VARS['NEWSFEED_ENCODING'] :
	    $HTTP_GET_VARS['NEWSFEED_ENCODING']);

    $newsfeed_username = str_replace("\'", "''",
	    trim((isset($HTTP_POST_VARS['NEWSFEED_USERNAME'])) ?
	    $HTTP_POST_VARS['NEWSFEED_USERNAME'] :
	    $HTTP_GET_VARS['NEWSFEED_USERNAME']));

    $newsfeed_inc_channel = ((isset($HTTP_POST_VARS['NEWSFEED_INC_CHANNEL'])) ?
	    intval($HTTP_POST_VARS['NEWSFEED_INC_CHANNEL']) :
	    ((isset($HTTP_GET_VARS['NEWSFEED_INC_CHANNEL'])) ?
	    intval($HTTP_GET_VARS['NEWSFEED_INC_CHANNEL']) : 0 ));

    $newsfeed_inc_image = ((isset($HTTP_POST_VARS['NEWSFEED_INC_IMAGE'])) ?
	    intval($HTTP_POST_VARS['NEWSFEED_INC_IMAGE']) :
	    ((isset($HTTP_GET_VARS['NEWSFEED_INC_IMAGE']) ) ?
	    intval($HTTP_GET_VARS['NEWSFEED_INC_IMAGE']) : 0 ));

    $newsfeed_single_post = ((isset($HTTP_POST_VARS['NEWSFEED_SINGLE_POST']) ) ?
	    intval($HTTP_POST_VARS['NEWSFEED_SINGLE_POST']) :
	    ((isset($HTTP_GET_VARS['NEWSFEED_SINGLE_POST']) ) ?
	    intval($HTTP_GET_VARS['NEWSFEED_SINGLE_POST']) : 0 ));

    $newsfeed_use_html = ((isset($HTTP_POST_VARS['NEWSFEED_USE_HTML']) ) ?
	    intval($HTTP_POST_VARS['NEWSFEED_USE_HTML']) :
	    ((isset($HTTP_GET_VARS['NEWSFEED_USE_HTML']) ) ?
	    intval($HTTP_GET_VARS['NEWSFEED_USE_HTML']) : 0 ));

    $newsfeed_topic_prefix = str_replace("\'", "''",
	    (isset($HTTP_POST_VARS['NEWSFEED_TOPIC_PREFIX']) ?
	    $HTTP_POST_VARS['NEWSFEED_TOPIC_PREFIX'] :
	    $HTTP_GET_VARS['NEWSFEED_TOPIC_PREFIX']));

    $newsfeed_strip_topic = ((isset($HTTP_POST_VARS['NEWSFEED_STRIP_TOPIC'])) ?
	    intval($HTTP_POST_VARS['NEWSFEED_STRIP_TOPIC']) :
	    ((isset($HTTP_GET_VARS['NEWSFEED_STRIP_TOPIC'])) ? 
	    intval($HTTP_GET_VARS['NEWSFEED_STRIP_TOPIC']) : 0 ));

    $newsfeed_inc_icon = ((isset($HTTP_POST_VARS['NEWSFEED_INC_ICON'])) ?
	    intval($HTTP_POST_VARS['NEWSFEED_INC_ICON']) :
	    ((isset($HTTP_GET_VARS['NEWSFEED_INC_ICON'])) ? 
	    intval($HTTP_GET_VARS['NEWSFEED_INC_ICON']) : 0 ));

    $newsfeed_inc_title = ((isset($HTTP_POST_VARS['NEWSFEED_INC_TITLE'])) ?
	    intval($HTTP_POST_VARS['NEWSFEED_INC_TITLE']) :
	    ((isset($HTTP_GET_VARS['NEWSFEED_INC_TITLE'])) ? 
	    intval($HTTP_GET_VARS['NEWSFEED_INC_TITLE']) : 0 ));

    $newsfeed_inc_description =
	    ((isset($HTTP_POST_VARS['NEWSFEED_INC_DESCRIPTION'])) ?
	    intval($HTTP_POST_VARS['NEWSFEED_INC_DESCRIPTION']) :
	    ((isset($HTTP_GET_VARS['NEWSFEED_INC_DESCRIPTION'])) ? 
	    intval($HTTP_GET_VARS['NEWSFEED_INC_DESCRIPTION']) : 0 ));

    $newsfeed_inc_details = ((isset($HTTP_POST_VARS['NEWSFEED_INC_DETAILS'])) ?
	    intval($HTTP_POST_VARS['NEWSFEED_INC_DETAILS']) :
	    ((isset($HTTP_GET_VARS['NEWSFEED_INC_DETAILS'])) ? 
	    intval($HTTP_GET_VARS['NEWSFEED_INC_DETAILS']) : 0 ));

    $newsfeed_inc_content = ((isset($HTTP_POST_VARS['NEWSFEED_INC_CONTENT'])) ?
	    intval($HTTP_POST_VARS['NEWSFEED_INC_CONTENT']) :
	    ((isset($HTTP_GET_VARS['NEWSFEED_INC_CONTENT'])) ?
	    intval($HTTP_GET_VARS['NEWSFEED_INC_CONTENT']) : 0 ));

    $newsfeed_inc_readmore = ((isset($HTTP_POST_VARS['NEWSFEED_INC_READMORE'])) ?
	    intval($HTTP_POST_VARS['NEWSFEED_INC_READMORE']) :
	    ((isset($HTTP_GET_VARS['NEWSFEED_INC_READMORE'])) ?
	    intval($HTTP_GET_VARS['NEWSFEED_INC_READMORE']) : 0 ));

    $newsfeed_is_podcast = ((isset($HTTP_POST_VARS['NEWSFEED_IS_PODCAST'])) ?
	    intval($HTTP_POST_VARS['NEWSFEED_IS_PODCAST']) :
	    ((isset($HTTP_GET_VARS['NEWSFEED_IS_PODCAST'])) ?
	    intval($HTTP_GET_VARS['NEWSFEED_IS_PODCAST']) : 0 ));

    $newsfeed_strip_images = ((isset($HTTP_POST_VARS['NEWSFEED_STRIP_IMAGES'])) ?
	    intval($HTTP_POST_VARS['NEWSFEED_STRIP_IMAGES']) :
	    ((isset($HTTP_GET_VARS['NEWSFEED_STRIP_IMAGES'])) ?
	    intval($HTTP_GET_VARS['NEWSFEED_STRIP_IMAGES']) : 0 ));

    // Do we have a valid forum_id?  This should always be ok as it uses a
    // drop down list for selection.
    if ($forum_id <= 0)
    {
	message_die(GENERAL_ERROR, "Can't create a newsfeed without an associated forum");
    }

    // Have they entered a url for the newsfeed?  It'd be pretty useless
    // without one.
    if(empty($newsfeed_url))
    {
	message_die(GENERAL_ERROR, "Can't create a newsfeed without a URL");
    }

    // Manually set to the default if missing.
    if (empty($newsfeed_encoding))
    {
        $newsfeed_encoding = 'Detect';
    }

    // Have they entered a username for the newsfeed?  Somebody has to
    // gather the news, it won't gather itself!
    if(empty($newsfeed_username))
    {
	message_die(GENERAL_ERROR, "Can't create a newsfeed without a valid user");
    }

    // Check to see if they've entered a valid username.
    $sql = "SELECT user_id FROM " . USERS_TABLE . " WHERE username='$newsfeed_username'";

    if(!($result = $db->sql_query($sql)))
    {
	message_die(GENERAL_ERROR, "Could not obtain user info.", "", __LINE__, __FILE__, $sql);
    }

    if (($row = $db->sql_fetchrow($result)))
    {
        $userid = $row['user_id'];
    }
    else
    {
	message_die(GENERAL_ERROR, "No users match that username.");
    }

    // If we are adding a new newsfeed...
    if ($mode == 'add')
    {
	// Check to see if the newsfeed url is already being used in the
	// chosen forum.
	$sql = "SELECT feed_id from " . NEWSFEEDS_TABLE .
	       " WHERE forum_id=$forum_id AND news_url='$newsfeed_url'";

        if (!($result = $db->sql_query($sql)))
        {
	    message_die(GENERAL_ERROR, "Could not obtain newsfeed info.", "", 
			__LINE__, __FILE__, $sql);
        }

        // Insert the new newsfeed details.
        if (!($row = $db->sql_fetchrow($result)))
        {
		$sql = "INSERT INTO " . NEWSFEEDS_TABLE .
			"(forum_id,
			user_id,
			news_url,
			news_name,
			news_limit,
			news_encoding,
			include_channel,
			include_image,
			topic_prefix,
			strip_topic,
			single_post,
			use_html,
			include_icon,
			include_title,
			include_description,
			include_details,
			include_content,
			include_readmore,
			is_podcast,
			strip_images)
                      VALUES
		      ($forum_id,
		       $userid,
		       '$newsfeed_url',
		       '$newsfeed_name',
		       $newsfeed_limit,
		       '$newsfeed_encoding',
		       $newsfeed_inc_channel,
		       $newsfeed_inc_image,
		       '$newsfeed_topic_prefix',
		       $newsfeed_strip_topic,
		       $newsfeed_single_post,
		       $newsfeed_use_html,
		       $newsfeed_inc_icon,
		       $newsfeed_inc_title,
		       $newsfeed_inc_description,
		       $newsfeed_inc_details,
		       $newsfeed_inc_content,
		       $newsfeed_inc_readmore,
		       $newsfeed_is_podcast,
		       $newsfeed_strip_images)";

    		if( !$result = $db->sql_query($sql) )
    		{
    		    message_die(GENERAL_ERROR, "Could not insert row in newsfeeds table.", "", __LINE__, __FILE__, $sql);
    		}
        }
        else
        {
    	    message_die(GENERAL_ERROR, "The URL entered already exists for this forum.");
        }
    }

    // We are saving the changes made to an existing newsfeed.
    else
    {
        // initialise the feed id
    	$feed_id = ( (isset($HTTP_POST_VARS['save_feed_id']) ) ? intval($HTTP_POST_VARS['save_feed_id']) :
                        ( (isset($HTTP_GET_VARS['save_feed_id']) ) ? intval($HTTP_GET_VARS['save_feed_id']) : 0 ));

        // if it's a valid newsfeed id, go ahead and do the update
        if ($feed_id > 0)
        {
            $sql = "UPDATE " . NEWSFEEDS_TABLE . "
                SET forum_id = $forum_id,
                    user_id = $userid,
                    news_url = '$newsfeed_url',
                    news_name = '$newsfeed_name',
		    news_limit = $newsfeed_limit,
		    news_encoding = '$newsfeed_encoding',
                    include_channel = $newsfeed_inc_channel,
		    include_image = $newsfeed_inc_image,
		    topic_prefix = '$newsfeed_topic_prefix',
		    strip_topic = $newsfeed_strip_topic,
		    single_post = $newsfeed_single_post,
		    use_html = $newsfeed_use_html,
		    include_icon = $newsfeed_inc_icon,
		    include_title = $newsfeed_inc_title,
		    include_description = $newsfeed_inc_description,
		    include_details = $newsfeed_inc_details,
		    include_content = $newsfeed_inc_content,
		    include_readmore = $newsfeed_inc_readmore,
                    is_podcast = $newsfeed_is_podcast,
		    strip_images= $newsfeed_strip_images
		WHERE feed_id = $feed_id";

    	    if (!($result = $db->sql_query($sql)))
    	    {
	      message_die(GENERAL_ERROR, "Could not update info in newsfeeds table.",
			    "", __LINE__, __FILE__, $sql);
    	    }
        }
    }
}

// Are we deleting an existing newsfeed?
elseif ( $mode == 'delete' )
{
    // Could be more than 1, get the list of feed ids to delete.
    $feeds = (isset($HTTP_POST_VARS['feed_id_list'])) ?  $HTTP_POST_VARS['feed_id_list'] : array();
    $feed_id_sql = '';

    // if we've got some feed ids, then go ahead and delete them
    if (count($feeds) > 0)
    {
    	for ($i = 0; $i < count($feeds); $i++)
    	{
    	  $feed_id_sql .= ( ( $feed_id_sql != '' ) ? ', ' : 'IN (' ) . $feeds[$i];
    	}
        $feed_id_sql .= ( $feed_id_sql != '' ) ? ')' : '';

        $sql = "DELETE FROM " . NEWSFEEDS_TABLE . " WHERE feed_id $feed_id_sql";
        if( !$result = $db->sql_query($sql) )
        {
            message_die(GENERAL_ERROR, "Could not delete from newsfeeds table.", "", __LINE__, __FILE__, $sql);
        }
    }
    else
    {
        message_die(GENERAL_ERROR, "None selected.");
    }
}

// are manaually gatheing the news?
elseif ( $mode == 'execute' )
{
    // call the news gathering function in functions_news.php
    include_once($phpbb_root_path . 'includes/find_functionsNews.php');

    $feeds = ( isset($HTTP_POST_VARS['feed_id_list']) ) ?
	    implode(',', $HTTP_POST_VARS['feed_id_list']) : '';
    $message = retrieve_rss_content($feeds, true);
    message_die(GENERAL_MESSAGE, $message);
}

// We are displaying a specific newsfeed?
elseif ( $mode == 'edit' )
{
    // Initialise the feed id.
    $feed_id = ((isset($HTTP_POST_VARS[POST_NEWSFEED_URL]) ) ?
	         intval($HTTP_POST_VARS[POST_NEWSFEED_URL]) :
		(isset($HTTP_GET_VARS[POST_NEWSFEED_URL]) ) ?
		 intval($HTTP_GET_VARS[POST_NEWSFEED_URL]) : 0 );

    // If we have a valid feed id then get and output the feed details.
    if ($feed_id > 0)
    {
        $sql = 'SELECT n.*, u.username
            FROM ' . NEWSFEEDS_TABLE . ' n, ' . USERS_TABLE . ' u
            WHERE u.user_id = n.user_id
	    AND feed_id = ' . $feed_id;

        if (!($result = $db->sql_query($sql)))
        {
	    message_die(GENERAL_ERROR,
			"Could not retrieve info from newsfeeds table.",
			"", __LINE__, __FILE__, $sql);
	}

        if ($row = $db->sql_fetchrow($result))
	{
            $template->assign_block_vars('news_input', array(
	        'S_FORUM_SELECT' => getForumList($db, $row['forum_id']),
            	'EDIT_NEWSFEED_ID' => $row['feed_id'],
            	'EDIT_NEWSFEED_FORUM_ID' => $row['forum_id'],
            	'EDIT_NEWSFEED_NAME' => $row['news_name'],
            	'EDIT_NEWSFEED_URL' => $row['news_url'],
                'EDIT_NEWS_USER' => $row['username'],
                'EDIT_NEWS_LIMIT' => $row['news_limit'],
                'EDIT_NEWS_ENCODING_DETECT' => ($row['news_encoding'] == 'Detect') ? 'selected="yes"' : '',
                'EDIT_NEWS_ENCODING_UTF' => ($row['news_encoding'] == 'UTF-8') ? 'selected="yes"' : '',
                'EDIT_NEWS_ENCODING_ISO' => ($row['news_encoding'] == 'ISO-8859-1') ? 'selected="yes"' : '',
                'EDIT_NEWS_ENCODING_US' => ($row['news_encoding'] == 'US-ASCII') ? 'selected="yes"' : '',
                'EDIT_NEWS_ENCODING_WIN' => ($row['news_encoding'] == 'WINDOWS-1252') ? 'selected="yes"' : '',
                'EDIT_NEWS_INCLUDE_CHANNEL' => ($row['include_channel']) ? 'checked=checked' : '',
                'EDIT_NEWS_INCLUDE_IMAGE' => ($row['include_image']) ? 'checked=checked' : '',
                'EDIT_NEWS_TOPIC_PREFIX' => $row['topic_prefix'],
                'EDIT_NEWS_STRIP_TOPIC' => ($row['strip_topic']) ? 'checked=checked' : '',
                'EDIT_NEWS_SINGLE_POST' => ($row['single_post']) ? 'checked=checked' : '',
                'EDIT_NEWS_USE_HTML' => ($row['use_html']) ? 'checked=checked' : '',
		'EDIT_NEWS_INCLUDE_ICON' => ($row['include_icon']) ? 'checked=checked' : '',
		'EDIT_NEWS_INCLUDE_TITLE' => ($row['include_title']) ? 'checked=checked' : '',
		'EDIT_NEWS_INCLUDE_DESCRIPTION' => ($row['include_description']) ? 'checked=checked' : '',
		'EDIT_NEWS_INCLUDE_DETAILS' => ($row['include_details']) ? 'checked=checked' : '',
		'EDIT_NEWS_INCLUDE_CONTENT' => ($row['include_content']) ? 'checked=checked' : '',
                'EDIT_NEWS_INCLUDE_READMORE' => ($row['include_readmore']) ? 'checked=checked' : '',
                'EDIT_NEWS_IS_PODCAST' => ($row['is_podcast']) ? 'checked=checked' : '',
                'EDIT_NEWS_STRIP_IMAGES' => ($row['strip_images']) ? 'checked=checked' : '',
		'L_ADD_EDIT_NEWSFEED' => $lang['Edit_Feed'],
	        'S_ADD_EDIT_NEWSFEED' => 'edit_newsfeed')

            );
        }
    }
}
elseif ( $mode == 'new' )
{
    // Assing defaults where available.
    $template->assign_block_vars('news_input', array(
	'S_FORUM_SELECT' => getForumList($db, null),
        'EDIT_NEWSFEED_ID' => '',
        'EDIT_NEWSFEED_FORUM_ID' => '',
        'EDIT_NEWSFEED_NAME' => '',
        'EDIT_NEWSFEED_URL' => '',
        'EDIT_NEWS_USER' => '',
        'EDIT_NEWS_LIMIT' => '0',
        'EDIT_NEWS_ENCODING_DETECT' => 'selected="yes"',
        'EDIT_NEWS_ENCODING_UTF' => '',
        'EDIT_NEWS_ENCODING_ISO' => '',
        'EDIT_NEWS_ENCODING_US' => '',
        'EDIT_NEWS_ENCODING_WIN' => '',
        'EDIT_NEWS_INCLUDE_CHANNEL' => '',
        'EDIT_NEWS_INCLUDE_IMAGE' => '',
        'EDIT_NEWS_TOPIC_PREFIX' => '',
        'EDIT_NEWS_STRIP_TOPIC' => '',
	'EDIT_NEWS_SINGLE_POST' => '',
	'EDIT_NEWS_USE_HTML' => '',
        'EDIT_NEWS_INCLUDE_ICON' => 'checked=checked',
        'EDIT_NEWS_INCLUDE_TITLE' => 'checked=checked',
        'EDIT_NEWS_INCLUDE_DESCRIPTION' => 'checked=checked',
        'EDIT_NEWS_INCLUDE_DETAILS' => 'checked=checked',
        'EDIT_NEWS_INCLUDE_CONTENT' => '',
        'EDIT_NEWS_INCLUDE_READMORE' => 'checked=checked',
        'EDIT_NEWS_IS_PODCAST' => '',
        'EDIT_NEWS_STRIP_IMAGES' => '',
	'L_ADD_EDIT_NEWSFEED' => $lang['Add_Feed'],
        'S_ADD_EDIT_NEWSFEED' => 'add_newsfeed')
    );
}

// Start the page output.
$template->set_filenames(array(
    'body' => 'admin/newsfeeds_body.tpl')
);

$template->assign_vars(array(
    'L_FIND_EXPLAIN' => $lang['FIND_Explain'],
    'L_FORUM_NAME' => $lang['Forum_name'],
    'L_NEWSFEED_NAME' => $lang['News_Feed_Name'],
    'L_NEWSFEED_NAME_EXPLAIN' => $lang['News_Feed_Name_Explain'],
    'L_NEWSFEED_URL' => $lang['News_Feed_URL'],
    'L_NEWSFEED_URL_EXPLAIN' => $lang['News_URL_Explain'],
    'L_NEWSFEEDS_TITLE' => $lang['News_Feeds'],
    'L_NEWSFEEDS_EXPLAIN' => $lang['News_Feeds_Explain'],
    'L_NEWSFEEDS_VERSION' => $FIND_VERSION,
    'L_NEWSFEEDS_AUTHOR' => $FIND_AUTHOR,
    'L_EDIT_NEWSFEED' => $lang['Edit_Feed'],
    'L_NEWS_FORUMS_EXPLAIN' => $lang['News_Forums_Explain'],
    'L_NEWS_USER' => $lang['News_Username'],
    'L_NEWS_USERNAME_EXPLAIN' => $lang['News_Username_Explain'],
    'L_NEWS_LIMIT' => $lang['News_Limit'],
    'L_NEWS_LIMIT_EXPLAIN' => $lang['News_Limit_Explain'],
    'L_NEWS_ENCODING' => $lang['News_Encoding'],
    'L_NEWS_ENCODING_EXPLAIN' => $lang['News_Encoding_Explain'],
    'L_NEW_NEWSFEED' => $lang['New_Feed'],
    'L_DELETE' => $lang['Delete'],
    'L_GET_NEWS_NOW' => $lang['Get_News_Now'],
    'L_NEWS_INC_CHANNEL' => $lang['News_Include_Channel'],
    'L_NEWS_INC_CHANNEL_EXPLAIN' => $lang['News_Include_Channel_Explain'],
    'L_NEWS_INC_IMAGE' => $lang['News_Include_Image'],
    'L_NEWS_INC_IMAGE_EXPLAIN' => $lang['News_Include_Image_Explain'],
    'L_NEWS_TOPIC_PREFIX' => $lang['News_Topic_Prefix'],
    'L_NEWS_TOPIC_PREFIX_EXPLAIN' => $lang['News_Topic_Prefix_Explain'],
    'L_NEWS_STRIP_TOPIC' => $lang['News_Strip_Topic'],
    'L_NEWS_STRIP_TOPIC_EXPLAIN' => $lang['News_Strip_Topic_Explain'],
    'L_NEWS_SINGLE_POST' => $lang['News_Single_Post'],
    'L_NEWS_SINGLE_POST_EXPLAIN' => $lang['News_Single_Post_Explain'],
    'L_NEWS_USE_HTML' => $lang['News_Use_HTML'],
    'L_NEWS_USE_HTML_EXPLAIN' => $lang['News_Use_HTML_Explain'],
    'L_NEWS_INC_ICON' => $lang['News_Include_Icon'],
    'L_NEWS_INC_ICON_EXPLAIN' => $lang['News_Include_Icon_Explain'],
    'L_NEWS_INC_TITLE' => $lang['News_Include_Title'],
    'L_NEWS_INC_TITLE_EXPLAIN' => $lang['News_Include_Title_Explain'],
    'L_NEWS_INC_DESCRIPTION' => $lang['News_Include_Description'],
    'L_NEWS_INC_DESCRIPTION_EXPLAIN' => $lang['News_Include_Description_Explain'],
    'L_NEWS_INC_DETAILS' => $lang['News_Include_Details'],
    'L_NEWS_INC_DETAILS_EXPLAIN' => $lang['News_Include_Details_Explain'],
    'L_NEWS_INC_CONTENT' => $lang['News_Include_Content'],
    'L_NEWS_INC_CONTENT_EXPLAIN' => $lang['News_Include_Content_Explain'],
    'L_NEWS_INC_READMORE' => $lang['News_Include_ReadMore'],
    'L_NEWS_INC_READMORE_EXPLAIN' => $lang['News_Include_ReadMore_Explain'],
    'L_NEWS_IS_PODCAST' => $lang['News_Is_Podcast'],
    'L_NEWS_IS_PODCAST_EXPLAIN' => $lang['News_Is_Podcast_Explain'],
    'L_NEWS_STRIP_IMAGES' => $lang['News_Strip_Images'],
    'L_NEWS_STRIP_IMAGES_EXPLAIN' => $lang['News_Strip_Images_Explain'],
    'L_CHECK_ALL' => $lang['Check_All'],
    'L_UNCHECK_ALL' => $lang['UnCheck_All'],
    'L_NEWS_ACTION' => $lang['News_Action'],
    'POST_NEWSFEED_URL' => POST_NEWSFEED_URL,
    'S_FORM_ACTION' => append_sid("admin_newsfeeds.$phpEx"),
    'I_NEWS_BEAKRIGHT' => $phpbb_root_path . 'images/beakRight.gif',
    'I_NEWS_BEAKDOWN' => $phpbb_root_path . 'images/beakDown.gif',
    )
);

// Get the list of newsfeeds and related info.
$sql = 'SELECT f.forum_name, n.*, c.cat_id, c.cat_title, u.user_id, u.username
	FROM ' . NEWSFEEDS_TABLE . ' n, ' . FORUMS_TABLE . ' f, ' . CATEGORIES_TABLE . ' c, ' . USERS_TABLE . ' u
	WHERE f.forum_id = n.forum_id
        AND c.cat_id = f.cat_id
        AND u.user_id = n.user_id
    ORDER BY c.cat_order ASC, f.forum_order ASC, n.news_name ASC';

if (!($result = $db->sql_query($sql)))
{
    message_die(GENERAL_ERROR, "Couldn't obtain newsfeeds list", "", __LINE__, __FILE__, $sql);
}

// Loop through the newsfeeds.
$cat_id = -1;
$newsfeed_rows = $db->sql_fetchrowset($result);
for($i = 0; $i < count($newsfeed_rows); $i++)
{
    // is this the start of a new category
    if ( $newsfeed_rows[$i]['cat_id'] != $cat_id )
    {
    	$template->assign_block_vars('cat_row', array(
            'CAT_TITLE' => $newsfeed_rows[$i]['cat_title']
            )
        );
        $cat_id = $newsfeed_rows[$i]['cat_id'];
    }

    // assign the various newsfeed variables
    $newsfeed_url = ( $newsfeed_rows[$i]['news_name'] != "" ) ?
	    '<a href="' . $newsfeed_rows[$i]['news_url'] . '" target="_blank">' .
	    $newsfeed_rows[$i]['news_name'] . '</a>' : 
	    '<a href="' . $newsfeed_rows[$i]['news_url'] . '" target="_blank">' . 
	    $newsfeed_rows[$i]['news_url'] . '</a>';

    $template->assign_block_vars('cat_row.newsfeed_row', array(
        'NEWSFEED_ID' => $newsfeed_rows[$i]['feed_id'],
        'FORUM_ID' => $newsfeed_rows[$i]['forum_id'],
        'USER_ID' => $newsfeed_rows[$i]['user_id'],
        'S_FORUM_NAME' => $newsfeed_rows[$i]['forum_name'],
        'S_NEWSFEED_USERNAME' => $newsfeed_rows[$i]['username'],
        'S_NEWSFEED_URL' => $newsfeed_url,
        'S_NEWSFEED_LIMIT' => $newsfeed_rows[$i]['news_limit'],
        'S_NEWSFEED_ENCODING' => $newsfeed_rows[$i]['news_encoding'],
        'S_NEWSFEED_INC_CHANNEL' => ($newsfeed_rows[$i]['include_channel']) ? $lang['Yes'] : $lang['No'],
        'S_NEWSFEED_INC_IMAGE' => ($newsfeed_rows[$i]['include_image']) ? $lang['Yes'] : $lang['No'],
        'S_NEWSFEED_TOPIC_PREFIX' => $newsfeed_rows[$i]['topic_prefix'],
        'S_NEWSFEED_STRIP_TOPIC' => ($newsfeed_rows[$i]['strip_topic']) ? $lang['Yes'] : $lang['No'],
        'S_NEWSFEED_SINGLE_POST' => ($newsfeed_rows[$i]['single_post']) ? $lang['Yes'] : $lang['No'],
        'S_NEWSFEED_USE_HTML' => ($newsfeed_rows[$i]['use_html']) ? $lang['Yes'] : $lang['No'],
        'S_NEWSFEED_INC_ICON' => ($newsfeed_rows[$i]['include_icon']) ? $lang['Yes'] : $lang['No'],
        'S_NEWSFEED_INC_TITLE' => ($newsfeed_rows[$i]['include_title']) ? $lang['Yes'] : $lang['No'],
        'S_NEWSFEED_INC_DESCRIPTION' => ($newsfeed_rows[$i]['include_description']) ? $lang['Yes'] : $lang['No'],
        'S_NEWSFEED_INC_DETAILS' => ($newsfeed_rows[$i]['include_details']) ? $lang['Yes'] : $lang['No'],
        'S_NEWSFEED_INC_CONTENT' => ($newsfeed_rows[$i]['include_content']) ? $lang['Yes'] : $lang['No'],
        'S_NEWSFEED_INC_READMORE' => ($newsfeed_rows[$i]['include_readmore']) ? $lang['Yes'] : $lang['No'],
        'S_NEWSFEED_IS_PODCAST' => ($newsfeed_rows[$i]['is_podcast']) ? $lang['Yes'] : $lang['No'],
        'S_NEWSFEED_STRIP_IMAGES' => ($newsfeed_rows[$i]['strip_images']) ? $lang['Yes'] : $lang['No'],
        'U_NEWS_USER' => append_sid("admin_users.$phpEx" . '?mode=edit&' . POST_USERS_URL . '=' . $newsfeed_rows[$i]['user_id']),
        'U_EDITFEED' => append_sid("admin_newsfeeds.$phpEx" . '?mode=edit&amp;' . POST_NEWSFEED_URL . '=' . $newsfeed_rows[$i]['feed_id']),
		)
	);
}
$db->sql_freeresult($result);

// now lets ouput the whole shebang
include('./page_header_admin.'.$phpEx);

$template->pparse('body');

include('./page_footer_admin.'.$phpEx);
?>
