<?php
/***************************************************************************
 *				find_newsInsert.php
 *				-------------------
 *   Last Updated	:	Sunday, February 18, 2007
 *   By			:	John MacAuley - The Comic Haven
 *   E-mail		:	hacksaw@thecomichaven.com
 *
 *   Version		: 	1.2.0
 *
 *   Changes:
 *   1.1	- Added remote invoke option using private key.
 *
 ***************************************************************************/

// Make phpBB files think we are in the phpBB flow.
define ('IN_PHPBB', true);

$phpbb_root_path = './';

// Include the default php file extension.
include($phpbb_root_path . 'extension.inc');

// Do all the common setup operations including HTTP parameter parsing.
include($phpbb_root_path . 'common.'.$phpEx);

// Include our own local implementation files.
include($phpbb_root_path . 'includes/find_config.'.$phpEx);
include($phpbb_root_path . 'includes/find_functionsNews.'.$phpEx);

// Include the newsfeed lang_admin and phpBB lang_main files.
$use_lang = (!file_exists($phpbb_root_path . 'language/lang_' . $board_config['default_lang'] . '/lang_main.'.$phpEx)) ? 'english' : $board_config['default_lang'];
include($phpbb_root_path . 'language/lang_' . $use_lang . '/lang_main.' . $phpEx);

// $AUTH_KEY configured in find_config.php.
global $AUTH_KEY, $FIND_DEBUG;

// Try and set some system settings to hopefully get round problems with
// security settings on hosting providers.
@set_time_limit(120);
@ini_set("safe_mode", "0");
@ini_set("allow_url_fopen", "1");

// Dump basic access information.
if ($FIND_DEBUG)
{
    define('DEBUG', true);

    print("find_newsInsert.php: processing feeds at: " . date('l dS \of F Y h:i:s A') . ".<br />\n");

    // Is this a local request?
    if ($HTTP_SERVER_VARS['SERVER_ADDR'] == $HTTP_SERVER_VARS['REMOTE_ADDR'])
    {
        print("find_newsInsert.php: local update request(" . $HTTP_SERVER_VARS['SERVER_ADDR'] . ").<br />\n");
    }
    else
    {
        print("find_newsInsert.php: remote update request (" . $HTTP_SERVER_VARS['REMOTE_ADDR'] . ").<br />\n");
    }
    print("Length: " . strlen($HTTP_SERVER_VARS['SERVER_ADDR']));

    // Check to see is this is a remote authentication request.
    if ($AUTH_KEY != null && $HTTP_GET_VARS['key'] != null)
    {
        if (strcmp($HTTP_GET_VARS['key'], $AUTH_KEY) == 0)
        {
            print("find_newsInsert.php: supplied authentication key is valid.<br />\n");
        }
	else
	{
            print("find_newsInsert.php: supplied authentication key is invalid.<br />\n");
	}
    }

}

// Quick and nasty security check, it's not flawless but it should stop most attempts
$secure_check = false;
$flood_attempt = false;

if ( $HTTP_SERVER_VARS['SERVER_ADDR'] == $HTTP_SERVER_VARS['REMOTE_ADDR'] ||
	$AUTH_KEY != null && strcmp($HTTP_GET_VARS['key'], $AUTH_KEY) == 0)
{
    // The request appears to be coming from this server (e.g. from cron), or
    // from a secure remote connection so we'll let it through.
    $secure_check = true;

    // flood attempt - check the current time against the last session time
    // that this script was executed always give the find_newsInsert the same
    // unique seesion id so we can use the session time to check.
    $current_time = time();
    $user_id = -2;
    $user_ip = encode_ip($HTTP_SERVER_VARS['REMOTE_ADDR']);
    $page_id = PAGE_INDEX;
    $session_id = md5('netclectic_find_news_insert');
    $sql = 'SELECT * FROM ' . SESSIONS_TABLE . " WHERE session_id = '$session_id'";

    if ($result = $db->sql_query($sql))
    {
        if ($row = $db->sql_fetchrow($result))
        {
            $last_session_time = $row['session_start'];
            if ($current_time <= $last_session_time + $board_config['flood_interval'])
            {
                $flood_attempt = true;
            }
            else
            {
                $sql = 'UPDATE ' . SESSIONS_TABLE . "
                    SET session_start = $current_time, session_time = $current_time
                    WHERE session_id = '$session_id'";
                if (!$db->sql_query($sql))
                {
            	  message_die(CRITICAL_ERROR, 'Error updating newsfeed session', '', __LINE__, __FILE__, $sql);
                }
            }
        }
        else
        {
            $sql = 'INSERT INTO ' . SESSIONS_TABLE . "
		(session_id, session_user_id, session_start, session_time, session_ip, session_page, session_logged_in)
		VALUES ('$session_id', $user_id, $current_time, $current_time, '$user_ip', $page_id, 0)";
            if (!$db->sql_query($sql))
            {
        	message_die(CRITICAL_ERROR, 'Error updating newsfeed session', '', __LINE__, __FILE__, $sql);
            }
        }
    }
}
else
{
    // If the request is not coming from this server, then check to see if
    // it's being executed by a logged in admin user.
    if ($FIND_DEBUG)
    {
	    print("find_newsInsert.php: verifying valid admin session.<br />\n");
	    print(">>>>>>>>>>>>>>>>>> <br />\n");
    }

    $userdata = session_pagestart($user_ip, PAGE_INDEX);
    init_userprefs($userdata);
    $secure_check = ($userdata['user_level'] == ADMIN);

    if ($FIND_DEBUG)
    {
	print("<<<<<<<<<<<<<<<<<< <br />\n");
	print("find_newsInsert.php: <b>Warning</b> messages above indicate an issue with the user session.<br />\n");
    }

}

// Dump state variables for debug.
if ($FIND_DEBUG)
{
    $secure_state = ($secure_check) ? "true" : "false";
    $flood_state = ($flood_attempt) ? "true" : "false";
    print("find_newsInsert.php: secure_check = " . $secure_state . "; flood_attempt = " . $flood_state . ".<br />\n");
}

if ( $secure_check && !$flood_attempt )
{
    // Do the news insert operation.
    $feeds = (isset($HTTP_GET_VARS[POST_NEWSFEED_URL])) ?  $HTTP_GET_VARS[POST_NEWSFEED_URL] : '';

    if ($FIND_DEBUG)
    {
        print("find_newsInsert.php: processing feeds (" . $feeds . ").<br />\n");
    }

    $msg = retrieve_rss_content($feeds, false);

    if ($FIND_DEBUG)
    {
        print("find_newsInsert.php: done processing feeds. <br />\n");
	print($msg . "<br />\n");
    }

    die($msg);
}
else
{
    if ($FIND_DEBUG)
    {
        print("find_newsInsert.php: hacking attempt - terminating.<br />\n");
    }

    die('Hacking attempt');
}
?>
