<?php
/***************************************************************************
 *                          find_functionsFormat.php
 *                          ------------------------
 *   Description:
 *   	This module contains functions handling the conversion between HTML
 *   	and bbcode for use during news post formatting.  Only basic formatting
 *   	is covered.  If you encounter a feed that fails conversion
 *   	modifications can be done in this file to handle the translation.
 *
 *   Last Updated	:	Sunday, February 18, 2007
 *   By             :	John MacAuley - The Comic Haven
 *   E-mail         :	hacksaw@thecomichaven.com
 *
 *   Version		: 	1.2.0
 *
 *   Changes:
 *   1.2.0  - Added more advanced parsing capabilities for RSS items and
 *            handling of special URL encoding.
 *   1.1	- Created separate functions.
 *
 ***************************************************************************/

// phpBB globals used for includes.
global $phpbb_root_path, $phpEx;

// Make sure someone isn't trying to invoke this directly.
if ( !defined('IN_PHPBB') )
{
	die('Hacking attempt');
}

// Include all the files we will need.
include($phpbb_root_path . 'includes/find_config.'.$phpEx);
include($phpbb_root_path . 'includes/find_htmlParser.'.$phpEx);

/***************************************************************************
 *                         stripHTML
 *                         ---------
 *   Description:
 *   	This function removes all unwanted HTML tags from a string.
 *
 *   Last Updated	:	Wednesday, August 23, 2006
 *   By             :	John MacAuley - The Comic Haven
 *   E-mail         :	hacksaw@thecomichaven.com
 *
 *   Version		: 	1.1
 *
 *   Changes:
 *   1.1	- Created.
 *
 *   Parameters:
 *       $string	- String to remove HTML tags.
 *
 *   Returns:
 *       String		- A cleaned string.
 *
 ***************************************************************************/
function stripHTML($string)
{
    $search = array(
        '@<script[^>]*?>.*?</script>@si',  // JavaScript.
        '@<[\/\!]*?[^<>]*?>@si',           // HTML tags.
        '@<style[^>]*?>.*?</style>@si',    // HTML style tags.
        '@&nbsp;@siU'
    );

    $replace = array(
        '',
        '',
        '',
        ' '
    );

    $string = preg_replace($search, $replace, $string);

    return($string);

} /* stripHTML() */


/***************************************************************************
 *                         stripBBcode
 *                         ---------
 *   Description:
 *   	This function removes all unwanted BBCode tags from a string.
 *
 *   Last Updated	:	Wednesday, August 23, 2006
 *   By             :	John MacAuley - The Comic Haven
 *   E-mail         :	hacksaw@thecomichaven.com
 *
 *   Version		: 	1.1
 *
 *   Changes:
 *   1.1	- Created.
 *
 *   Parameters:
 *       $string	- String to remove bbcode tags.
 *
 *   Returns:
 *       String		- A cleaned string.
 *
 ***************************************************************************/
function stripBBcode($string)
{
    $search = array(
	'@\[b\]@si',
	'@\[/b\]@si',
	'@\[i\]@si',
	'@\[/i\]@si',
	'@\[u\]@si',
	'@\[/u\]@si',
	'@\[img\]@si',
	'@\[/img\]@si',
	'@\[code]@si',
	'@\[/code\]@si',
	'@\[url(.+)?\]@si',
	'@\[/url\]@si',
	'@\[quote(.+)?\]@si',
	'@\[/quote\]@si',
	'@\[size(.+)?\]@si',
	'@\[/size\]@si',
	'@\[list(.+)?\]@si',
	'@\[/list\]@si',
	'@\[hide(.+)?\]@si',
	'@\[/hide\]@si'
    );

    $string = preg_replace($search, '', $string);

    return($string);

} /* stripBBcode() */


/***************************************************************************
 *                         stripClean
 *                         ---------
 *   Description:
 *   	This function removes all unwanted HTML and bbcode tags from a string,
 *   	including hard spaces and newline characters.
 *
 *   Last Updated	:	Wednesday, August 23, 2006
 *   By             :	John MacAuley - The Comic Haven
 *   E-mail         :	hacksaw@thecomichaven.com
 *
 *   Version		: 	1.1
 *
 *   Changes:
 *   1.1	- Created.
 *
 *   Parameters:
 *       $string	- String to remove HTML tags.
 *
 *   Returns:
 *       String		- A cleaned string.
 *
 ***************************************************************************/
function stripClean($string)
{
// HTML formatting tags that are substituted with equivalent bbcode, or
// removed as needed.  Add to list when feeds are discovered that contain
// formatting not listed here.  Not all tags can be removed using this
// simple mechanism.  More general rules can be created over time.
//
// It should be noted that some RSS feeds are including character
// encodings that do not match the encoding specified in the file header.  In
// these cases some characters may be replaced with alternative characters
// by the xml parser, and therefore, will not be picked up by the following
// rules.

    $string = html_entity_decode($string);
    $string = stripslashes($string);
    $string = stripHTML($string);
    $string = stripBBcode($string);
    $string = preg_replace("@\n@si", '', $string); // newlines.

    return($string);

} /* stripClean() */

/***************************************************************************
 *                         stripBrackets
 *                         -------------
 *   Description:
 *   	This function removes any brackets and the contents between them
 *   	that may occur in some feeds at the start of a subject.
 *
 *   Last Updated	:	Monday, February 12, 2007
 *   By             :	John MacAuley - The Comic Haven
 *   E-mail         :	hacksaw@thecomichaven.com
 *
 *   Version		: 	1.2.0
 *
 *   Changes:
 *   1.2	- Created.
 *
 *   Parameters:
 *       $string	- String to remove brackets.
 *
 *   Returns:
 *       String		- A cleaned string.
 *
 ***************************************************************************/
function stripBrackets($string)
{
    $searchBrackets = array(
	'@^(\[.+\])(.+)@s',
	'@^(\{.+\})(.+)@s',
	'@^(\(.+\))(.+)@s'
    );

    $replaceBrackets = array(
	'\2',
	'\2',
	'\2'
    );

    $searchWhitespace = array(
	'@^[ \t]+@s',
	'@[ \t]+$@s',
    );

    $replaceWhitespace = array(
	'',
	'',
    );

    // Strip any leading or trailing whitespace before we clean.
    $string = preg_replace($searchWhitespace, $replaceWhitespace, $string);

    // Remove the brackets only at the start of a line.
    $string = preg_replace($searchBrackets, $replaceBrackets, $string);

    // Clean up the resulting string to remove any leading whitespace we
    // may have introduced.
    $string = preg_replace($searchWhitespace, $replaceWhitespace, $string);

    return($string);

} /* stripBrackets() */

/***************************************************************************
 *                         stripHREF
 *                         ---------
 *   Description:
 *   	This function removes unwanted characters from an HREF string and
 *   	attempts to return only the component URL.  More specifically, if
 *   	there is any javascript in the HREF we strip it out.  This function
 *   	will also strip out an embeeded URL returned from a yahoo news rss
 *   	feed.  In the future more processing can be include when needed.
 *
 *   Last Updated	:	Monday, February 12, 2007
 *   By             :	John MacAuley - The Comic Haven
 *   E-mail         :	hacksaw@thecomichaven.com
 *
 *   Version		: 	1.2.0
 *
 *   Changes:
 *   1.2.0  - Added additional parsing options for google news.
 *   1.1	- Created.
 *
 *   Parameters:
 *       $string	- String to remove stuff.
 *
 *   Returns:
 *       String		- A cleaned string.
 *
 ***************************************************************************/
$hrefTypes = array ("http://", "ftp://", "mailto:");

function stripHREF($string)
{
	global $DEFAULT_LINK, $hrefTypes;

	$urlTypes = array ("&url=");

	// We want to find an embedded URL in the provided string.
	$string = urldecode($string);
	$temp = strtolower($string);

	// Handle each of the specific Google URL encodings.
	foreach ($urlTypes as $type)
	{
		$start = strpos($temp, $type);

		if (!($start === FALSE))
		{
			// Strip to the start of the URL.
			$result = substr($string, $start + strlen($type));

			// Now we need to remove the end parameters.
			$temp = strtolower($result);
                        $end = strpos($temp, "&cid=");
			if (!($end === FALSE))
			{
			    $result = substr($result, 0, $end);
			}
			return($result);
		}
	}

	// Check for the yahoo embedded URL.
       $start = strpos($temp, "*http://");

	if (!($start === FALSE))
	{
		$result = substr($string, $start + 1);
		return($result);
	}

	// See if there is any embedded javascript.
	$start = strpos($temp, "javascript");

	if (!($start === FALSE))
	{
		// Strip out the embedded URL - this is a hack...
		$result = $DEFAULT_LINK;
		foreach ($hrefTypes as $type)
		{
			// Find a matching href type.
	    		$start = strpos($temp, $type);
			if ($start === FALSE)
			{
				continue;
			}
	
			// Determine quote type around URL and strip start.
			$quote = substr($temp, $start - 1, 1);
			$temp = substr($temp, $start);

			// Locate the first matching quote.
			$end = strpos($temp, $quote);

			if ($end === FALSE)
			{
				// We are all screwed up.
				break;
			}

			$result = substr($string, $start, $end);
			break;
		}

		return($result);
	}

	return($string);

} /* stripHREF() */


/***************************************************************************
 *                         stripImageURL
 *                         -------------
 *   Description:
 *   	This function removes unwanted characters from an image string and
 *   	attempts to return only the component URL.  In the future more
 *   	processing can be include when needed.
 *
 *   Last Updated	:	Monday, February 12, 2007
 *   By             :	John MacAuley - The Comic Haven
 *   E-mail         :	hacksaw@thecomichaven.com
 *
 *   Version		: 	1.2.0
 *
 *   Changes:
 *   1.2.0  - Added additional parsing options for google news images.
 *   1.1	- Created.
 *
 *   Parameters:
 *       $string	- URL string.
 *
 *   Returns:
 *       String		- A clean URL.
 *
 ***************************************************************************/
function stripImageURL($string)
{
	$urlTypes = array ("&imgurl=", "&url=");

	// We want to find an embedded URL in the provided string.
	$string = urldecode($string);
	$temp = strtolower($string);

	// Handle each of the specific Google image URL encodings.
	foreach ($urlTypes as $type)
	{
		$start = strpos($temp, $type);

		if (!($start === FALSE))
		{
			// Strip out the URL.
			$string = 'http://' . substr($string, $start + strlen($type));
		}
	}

	$end = strpos($string, "?");
	if (!($end === FALSE))
	{
		$string = substr($string, 0, $end);
	}

	// There are special characters in a URL that cannot be displayed
	// properly by phpBB.  We will need to invalidate the URL if these
	// characters are present.
	if (!(strpos($string, "~") === FALSE))
	{
		$string = "";
	}
	
	return($string);


} /* stripImageURL() */


/***************************************************************************
 *                         typeURL
 *                         -------
 *   Description:
 *   	This function returns the type of URL reference held in the string.
 *   	If this is a relative URL a type of unkown will be returned.  These
 *   	cannot be used in the bbcode [url] type anyway so we should be okay.
 *
 *   Last Updated	:	Wednesday, August 30, 2006
 *   By             :	John MacAuley - The Comic Haven
 *   E-mail         :	hacksaw@thecomichaven.com
 *
 *   Version		: 	1.1
 *
 *   Changes:
 *   1.1	- Created.
 *
 *   Parameters:
 *       $string	- String holding the URL.
 *
 *   Returns:
 *       Integer	- The integer matching the URL type.
 *
 ***************************************************************************/
define ("URL_TYPE_UNKNOWN", 0);
define ("URL_TYPE_HTTP",    1);
define ("URL_TYPE_FTP",     2);
define ("URL_TYPE_MAILTO",  3);

function typeURL($string)
{
	global $hrefTypes;

	$temp = strtolower($string);

	$i = 0;
	foreach ($hrefTypes as $type)
	{
		$i = $i + 1;
		// Find a matching href type.
	    	$start = strpos($temp, $type);
		if ($start === FALSE)
		{
                  continue;
		}

		return($i);
	}

	return(URL_TYPE_UNKNOWN);

} /* typeURL() */

function isaLink($url)
{
    // Verify we have valid URLs.
    $isURL = typeURL($url);
    if ($isURL != URL_TYPE_HTTP && $isURL != URL_TYPE_FTP)
    {
        $url = null;
    }

    return($url);
} /* isaLink() */

/***************************************************************************
 *                         stripMailTo
 *                         -----------
 *   Description:
 *   	This function extracts the e-mail address from a mailto URL. 
 *
 *   Last Updated	:	Thursday, September 14, 2006
 *   By             :	John MacAuley - The Comic Haven
 *   E-mail         :	hacksaw@thecomichaven.com
 *
 *   Version		: 	1.1
 *
 *   Changes:
 *   1.1	- Created.
 *
 *   Parameters:
 *       $string	- Mailto URL string.
 *
 *   Returns:
 *       String		- e-mail address.
 *
 ***************************************************************************/
function stripMailTo($string)
{
	$email = strtolower($string);
	$pos = strpos($email, "mailto:");

	if ($pos === FALSE)
	{
		return($email);
	}

	$email = substr($email, $pos + 7);

	return($email);

} /* stripMailTo() */


/***************************************************************************
 *                         allhtmlentities
 *                         ---------------
 *   Description:
 *   	This function decodes html entities into their #xxxx equivalent. 
 *
 *   Last Updated	:	Sunday, February 18, 2007
 *   By             :	John MacAuley - The Comic Haven
 *   E-mail         :	hacksaw@thecomichaven.com
 *
 *   Version		: 	1.2.0
 *
 *   Changes:
 *   1.2.0	- Created.
 *
 *   Parameters:
 *       $string	- String to decode.
 *
 *   Returns:
 *       String		- Processed string.
 *
 ***************************************************************************/
function allhtmlentities($string, $decode_first=true)
{
    // This is to ensure that any entities already coded are not "messed up".
    if($decode_first)
    {
        $string = html_entity_decode($string);
        $string = preg_replace('@%([0-9a-f][0-9a-f])@ei', 'chr(hexdec("\\1"))', $string);
    }

    // "encode".
    return preg_replace('/([\x20-\x22]|[\x28-\x29]|[\x5B-\x5E]|[\x7B-\x7E])/e',
                        '"&#".ord("$0").";"', $string);
                        
} /* allhtmlentities() */


/***************************************************************************
 *                         parseHTML2BBcode
 *                         ----------------
 *   Description:
 *   	This function uses an HTML parser to handle conversion of HTML tags
 *   	to bbcode.  Any HMTL code not converted will be dropped from the
 *   	string. 
 *
 *   Last Updated	:	Wednesday, August 30, 2006
 *   By             :	John MacAuley - The Comic Haven
 *   E-mail         :	hacksaw@thecomichaven.com
 *
 *   Version		: 	1.1
 *
 *   Changes:
 *   1.1	- Created.
 *
 *   Parameters:
 *       $string	- String holding the html code to convert.
 *
 *   Returns:
 *       String		- The converted string.
 *
 ***************************************************************************/
function parseHTML2BBcode($string, $stripImages = false)
{
	// We use an external HTML parser to handle the basics.
	$parser = new HtmlParser($string);

	// We will populate the $result string with converted text.
	$result = '';

	// We need to keep a few state variables to know where we are in the
	// parsing of tags.
	$in_textarea = false;
	$fontStack = array();
	$colorOpen = false;
	$sizeOpen = false;
	$boldCount = 0;
	$italicCount = 0;
        $dropContents = false;
        $closeURL = false;
        $textOutput = false;

	while ($parser->parse())
	{
		// The parser will return tags as-is, but we need to compare
		// tags using lowercase.
		$nodeName = strtolower($parser->iNodeName);
		$nodeType = $parser->iNodeType;

		switch($nodeType)
		{
			case NODE_TYPE_TEXT:
				// Regular text so we add this untouched.
				if ($dropContents != true)
				{
					$result .= $parser->iNodeValue;
					$textOutput = true;
				}
				break;

			case NODE_TYPE_COMMENT:
				// Drop comments for now.
				break;

			case NODE_TYPE_ELEMENT:
				// Assumption: no nested <a href> elements.
       				$attrValues = $parser->iNodeAttributes;
       				$attrNames = array_keys($attrValues);
       				$size = count($attrNames);

				switch ($nodeName)
				{
					case "a":
						$closeURL = false;
	
						// We have a link so find the href attribute.
						for ($i = 0; $i < $size; $i++)
						{
		    					$name = $attrNames[$i];
		    					if (strcmp(strtolower($name), "href") == 0)
							{
								// Remove any crap from the string.
								$stripped = stripHREF($attrValues[$name]);
                      						$type = typeURL($stripped);
	
		      						if ($type == URL_TYPE_HTTP || $type == URL_TYPE_FTP)
								{
									$stripped = allhtmlentities($stripped, true);
			      						$result .= '[url=' . $stripped . ']';
									$closeURL = true;
									$textOutput = false;
		      						}
		      						else if ($type == URL_TYPE_MAILTO)
		      						{
									$result .= '[email]' . stripMailTo($stripped) . '[/email]';
									$dropContents = true;
		      						}
	
		      						// This was all we were looking for.
		      						break;
		    					}
						}
						break;

					case "b":
						if ($boldCount == 0)
						{
							$result .= '[b]';
						}
						$boldCount++;
						break;

					case "big":
						$result .= '[b]';
						break;

					case "blockquote":
						$result .= '[quote]';
						break;

					case "br":
						if ($closeURL == true && $stripImages == true && $textOutput == false)
						{
							// Do not put in a newline.
							break;
						}

						$result .= "\n";
						break;

					case "em":
						$result .= '[i]';
						break;

					case "font":
						// We have font element so find the size and color attributes.
						// TODO: Push open font elements on stack to handle nested
						// elements and ordering of the element close.  What was opened
						// can then be popped of the stack as end elements are encountered.

						$closeString = '';
						
						for ($i = 0; $i < $size; $i++)
						{
							$name = strtolower($attrNames[$i]);

							switch($name)
							{
							case "color":
								if ($colorOpen == false)
								{
									$result .= '[color=' . $attrValues[$attrNames[$i]] . ']';
									$closeString = '[/color]' . $closeString;
									$colorOpen = true;
								}
								break;

							case "size":
								if ($sizeOpen == false)
								{
									$size_value = intval($attrValues[$attrNames[$i]]);
									if ($size_value == 0)
									{
									  break;
									}

									if (!(strpos($attrValues[$attrNames[$i]], "+") === FALSE)
									    || !(strpos($attrValues[$attrNames[$i]], "-") === FALSE))
									{
										// We have a relative + size.
										$size_value = $size_value + 12;
									}
									else
									{
										// Use font size 10 as a starting point.
                                                                                $size_value = $size_value + 10;
                                                                        }

									$result .= '[size=' . $size_value . ']';
									$closeString = '[/size]' . $closeString;
									$sizeOpen = true;
								}
								break;
							default:
								break;
							}
						}

						array_push($fontStack, $closeString);
						break;

					case "i":
						if ($italicCount == 0)
						{
							$result .= '[i]';
						}
						$italicCount++;
						break;

					case "img":
						// Are we keeping images?
						if ($stripImages == true)
						{
							break;
						}

						// We have an image so find the src attribute.
						for ($i = 0; $i < $size; $i++)
						{
		    					$name = $attrNames[$i];
		    					if (strcmp(strtolower($name), "src") == 0)
							{
							    $image = stripImageURL($attrValues[$name]);
							    if (typeURL($image) == URL_TYPE_HTTP)
							    {
								    $result .= '[img]' . $image . '[/img]';
						                    $textOutput = true;
	                                                    }

		      					    // This is all we were looking for.
		      					    break;
		    					}
						}
						break;

					case "li":
						$result .= "-";
						break;

					case "ol":
						$result .= "[list=1]";
						break;

					case "p":
						$result .= "\n\n";
						break;

					case "pre":
						$result .= "[code]";
						break;

					case "strong":
						$result .= '[b]';
						break;

					case "td":
						$result .= ' ';
						break;


					case "textarea":
						$result .= '[code]';
						break;

					case "u":
						$result .= '[u]';
						break;

					case "ul":
						$result .= '[list]';
						break;

					default:
						// Drop the remaining tags.
						break;

				} /* switch ($nodeName) */
				break;

			case NODE_TYPE_ENDELEMENT:
	    			switch($nodeName)
	    			{
					case "a":
						if ($closeURL == true)
						{
							if ($textOutput == false)
							{
								$result .= " [link] ";
							}

				    			$result .= '[/url]';
							$closeURL = false;
						}

						$dropContents = false;
						break;

					case "b":
						if ($boldCount == 1)
						{
							$result .= '[/b]';
						}

						if ($boldCount > 0)
						{
							$boldCount--;
						}
						break;

					case "big":
						$result .= '[/b]';
						break;

					case "blockquote":
						$result .= '[/quote]';
						break;

					case "em":
						$result .= '[/i]';
						break;

					case "font":
						$closeString = array_pop($fontStack);

						if ($closeString != null)
			    			{
							$result .= $closeString;

							if (!(strpos($closeString, "[/size]") === FALSE))
							{
								$sizeOpen = false;
							}

							if (!(strpos($closeString, "[/color]") === FALSE))
							{
								$colorOpen = false;
							}
						}
						break;

					case "i":
						if ($italicCount == 1)
						{
							$result .= '[/i]';
						}

						if ($italicCount > 0)
						{
							$italicCount--;
						}
						break;

					case "li":
						$result .= "\n";
						break;

					case "ol":
						$result .= '[/list]';
						break;

					case "p":
						$result .= "\n";
						break;

					case "pre":
						$result .= '[/code]';
						break;

					case "strong":
						$result .= '[/b]';
						break;

					case "td":
						$result .= ' ';
						break;

					case "textarea":
						$result .= '[/code]';
						break;

					case "u":
						$result .= '[/u]';
						break;

					case "ul":
						$result .= '[/list]';
						break;

					default:
						// Ignore everything else.
						break;
				}
				break;

			case NODE_TYPE_START:
			case NODE_TYPE_DONE:
			default:
				// We can ignore these.
				break;
		} /* switch($nodeType) */
	}

	return($result);

} /* parseHTML2BBcode */


/***************************************************************************
 *                         cleanWhiteSpace
 *                         ---------------
 *   Description:
 *   	This function removes extra white space from a string. 
 *
 *   Last Updated	:	Wednesday, August 30, 2006
 *   By             :	John MacAuley - The Comic Haven
 *   E-mail         :	hacksaw@thecomichaven.com
 *
 *   Version		: 	1.1
 *
 *   Changes:
 *   1.1	- Created.
 *
 *   Parameters:
 *       $string	- String holding the text to clean.
 *
 *   Returns:
 *       String		- The clean string.
 *
 ***************************************************************************/
function cleanWhiteSpace($string)
{
    // HTML to bbcode conversion can introduce a lot of newlines into the
    // output so we want to remove a few before we start.
    $search = array(
	'#\\r#si',
	'# +\\n#si',
	'#\t+\\n#si',
	'#\\n\\n\\n#si',
	'#&nbsp;#si',
        '#&ndash;#si',
    );

    $replace = array(
	'',
	"\n",
	"\n",
	"\n\n",
	' ',
	'-',
    );

    // Do some cleanup after html parsing.
    $newString = preg_replace($search, $replace, $string);
    while (strcmp($newString, $string) != 0)
    {
	$string = $newString;
	$newString = preg_replace($search, $replace, $string);
    }

    $string = $newString;

    return($string);

} /* cleanWhiteSpace() */


/***************************************************************************
 *                         html2bbcode
 *                         ------------
 *   Description:
 *   	This function replaces formatting HTML tags in a string with
 *   	equivalent bbcode tags.  Some additional HTML and characters are
 *   	stripped.
 *
 *   Original Author	: 	John MacAuley - The Comic Haven
 *   E-mail             :	hacksaw@thecomichaven.com
 *   Created            :	Wednesday, March 14, 2007
 *
 *   Version            : 	1.2.0
 *
 *   Changes:
 *   1.2.0  - Added capability to strip images from the string.
 *   1.1	- Created.
 *
 *   Parameters:
 *       $string	   - String to replace HTML tags.
 *       $stripImages  - Boolean indicating if imahes should be stripped.
 *
 *   Returns:
 *       String		- A cleaned string.
 *
 ***************************************************************************/
function html2bbcode($string, $stripImages=false)
{
    global $FIND_DEBUG;

    $search = array(
        '@&nbsp;@si',
        '@&ndash;@si',
        '@&apos;@si',
        '@&quot;@si'
    );

    $replace = array(
        ' ',
        '-',
        "'",
        '"'
    ) ;

    // Decode special characteres and strip any uneeded slashes.
    $string = html_entity_decode($string);
    $string = stripslashes($string);

    // Replace html tags by parsing and drop those not needed.
    $string = parseHTML2BBcode($string, $stripImages);

    // Now convert any missed characters.
    $string = preg_replace($search, $replace, $string);

    if ($FIND_DEBUG)
    {
	    print("html2bbcode: <pre>" . $string . "</pre><br />\n");
    }

    return($string);

} /* html2bbcode() */


/***************************************************************************
 *                         bbcode2html
 *                         -----------
 *   Description:
 *   	This function replaces formatting BBCode tags in a string with
 *   	equivalent HMTL tags.
 *
 *   Original Author	: 	John MacAuley - The Comic Haven
 *   E-mail             :	hacksaw@thecomichaven.com
 *   Created            :	Wednesday, March 14, 2007
 *
 *   Version            : 	1.2.0
 *
 *   Changes:
 *   1.2.0  - Added capability to strip images from the string.
 *   1.1	- Created.
 *
 *   Parameters:
 *       $string	- String to replace HTML tags.
 *       $stripImages  - Boolean indicating if imahes should be stripped.
 *
 *   Returns:
 *       String		- A cleaned string.
 *
 ***************************************************************************/
//converts certain bbcode tags to html equivilents
function bbcode2html($string, $stripImages=false)
{
    $searchImage = array(
        '@\[img\]([a-z]+?://){1}(.*?)\[/img]@si',
        '@\[img\](.*?)\[/img\]@si'
    ) ;

    $replaceImage = array(
        '<img src="\1\2" />',
        '<img src="\1" />'
    ) ;

    $removeImage = array(
	'',
	''
    );

    $search = array(
        '@\[url\]([a-z]+?://){1}(.*?)\[/url]@si',
        '@\[url\](.*?)\[/url\]@si',
        '@\[url=([a-z]+?://){1}(.*?)\](.*?)\[/url]@si',
        '@\[b](.*?)\[/b\]@si',
        '@\[i](.*?)\[/i\]@si',
        '@\[u](.*?)\[/u\]@si'
    );

    $replace = array(
        '<a href="\1\2" target=\"_blank\">$1$2</a>',
        '<a href="http://\1\2" target=\"_blank\">\1</a>',
        '<a href="\1\2" target=\"_blank\">\3</a>',
        '<b>\1</b>',
        '<i>\1</i>',
        '<u>\1</u>'
    ) ;

    $htmlSearch = array(
        '@src=http([^ >]*)@si',
        '@href=http([^ >]*)@si',
        '@&nbsp;@si',
        '@&ndash;@si',
        '@&apos;@si',
        '@&quot;@si'
    );

    $htmlReplace = array(
        'src="http\1"',
        'href="http\1"',
        ' ',
        '-',
        "'",
        '"'
    ) ;
    
    // Decode special characteres and strip any uneeded slashes.
    $string = html_entity_decode($string);
    $string = stripslashes($string);

    // Strip images if needed.
    if ($stripImages == true)
    {
        $string = preg_replace($searchImage, $removeImage, $string);
        $string = preg_replace('@<img (.|\n)+?>@si', '', $string);
        $string = preg_replace('@<.img (.|\n)+?>@si', '', $string);
    }
    else
    {
        $string = preg_replace($searchImage, $replaceImage, $string);
    }

    // Replace any bbcode with HTML.
    $string = preg_replace($search, $replace, $string);

    // Clean up any offending HTML tags.
    $string = preg_replace($htmlSearch, $htmlReplace, $string);
    
    // Finally we want to strip any new lines.
    $string = preg_replace("@\n@si", '', $string);

    return($string);

} /* bbcode2html() */

?>
